==> jsdoc-to-markdown-0.5.3.tgz: package/test/fixture/output/commonjs/object-static-class.md <==

<a name="module_heaven"></a>
#heaven
factory module creating dodgy cloud. object-with-static-class.

**Members**

* [heaven](#module_heaven)
  * [heaven.Cloud](#module_heaven.Cloud)
  * [heaven.createCloud()](#module_heaven.createCloud)
  * [const: heaven~FACT](#module_heaven..FACT)
  * [class: heaven~Cloud](#module_heaven..Cloud)
    * [new heaven~Cloud(options)](#new_module_heaven..Cloud)
    * [cloud.size](#module_heaven..Cloud#size)
    * [cloud.rain](#module_heaven..Cloud#rain)
    * [Cloud.classMethod()](#module_heaven..Cloud.classMethod)
    * [const: Cloud.SPACES](#module_heaven..Cloud.SPACES)

<a name="module_heaven.Cloud"></a>
##heaven.Cloud
access to the Cloud class

**Type**: [Cloud](#new_module_heaven..Cloud)  
<a name="module_heaven.createCloud"></a>
##heaven.createCloud()
**Returns**: [Cloud](#new_module_heaven..Cloud)  
<a name="module_heaven..FACT"></a>
##const: heaven~FACT
an inner constant

**Scope**: inner constant of [heaven](#module_heaven)  
**Type**: `boolean`  
<a name="module_heaven..Cloud"></a>
##class: heaven~Cloud
The main class for a cloud

**Members**

* [class: heaven~Cloud](#module_heaven..Cloud)
  * [new heaven~Cloud(options)](#new_module_heaven..Cloud)
  * [cloud.size](#module_heaven..Cloud#size)
  * [cloud.rain](#module_heaven..Cloud#rain)
  * [Cloud.classMethod()](#module_heaven..Cloud.classMethod)
  * [const: Cloud.SPACES](#module_heaven..Cloud.SPACES)

<a name="new_module_heaven..Cloud"></a>
###new heaven~Cloud(options)
cloud constructor

**Params**

- options `object` - the options

**Scope**: inner class of [heaven](#module_heaven)  
<a name="module_heaven..Cloud#size"></a>
###cloud.size
**Type**: `number`  
**Default**: `4`  
<a name="module_heaven..Cloud#rain"></a>
###cloud.rain
**Type**: `boolean`  
**Default**: `false`  
<a name="module_heaven..Cloud.classMethod"></a>
###Cloud.classMethod()
a class method

<a name="module_heaven..Cloud.SPACES"></a>
###const: Cloud.SPACES
a class constant

**Type**: `number`

==> jsdoc-to-markdown-0.5.5.tgz: package/test/fixture/output/commonjs/object-static-class.md <==

<a name="module_heaven"></a>
#heaven
factory module creating dodgy cloud. object-with-static-class.

**Members**

* [heaven](#module_heaven)
  * [heaven.Cloud](#module_heaven.Cloud)
  * [heaven.createCloud()](#module_heaven.createCloud)
  * [const: heaven~FACT](#module_heaven..FACT)
  * [class: heaven~Cloud](#module_heaven..Cloud)
    * [new heaven~Cloud(options)](#new_module_heaven..Cloud)
    * [cloud.size](#module_heaven..Cloud#size)
    * [cloud.rain](#module_heaven..Cloud#rain)
    * [Cloud.classMethod()](#module_heaven..Cloud.classMethod)
    * [const: Cloud.SPACES](#module_heaven..Cloud.SPACES)

<a name="module_heaven.Cloud"></a>
##heaven.Cloud
access to the Cloud class

**Type**: [Cloud](#module_heaven..Cloud)  
<a name="module_heaven.createCloud"></a>
##heaven.createCloud()
**Returns**: [Cloud](#module_heaven..Cloud)  
<a name="module_heaven..FACT"></a>
##const: heaven~FACT
an inner constant

**Scope**: inner constant of [heaven](#module_heaven)  
**Type**: `boolean`  
<a name="module_heaven..Cloud"></a>
##class: heaven~Cloud
The main class for a cloud

**Members**

* [class: heaven~Cloud](#module_heaven..Cloud)
  * [new heaven~Cloud(options)](#new_module_heaven..Cloud)
  * [cloud.size](#module_heaven..Cloud#size)
  * [cloud.rain](#module_heaven..Cloud#rain)
  * [Cloud.classMethod()](#module_heaven..Cloud.classMethod)
  * [const: Cloud.SPACES](#module_heaven..Cloud.SPACES)

<a name="new_module_heaven..Cloud"></a>
###new heaven~Cloud(options)
cloud constructor

**Params**

- options `object` - the options

**Scope**: inner class of [heaven](#module_heaven)  
<a name="module_heaven..Cloud#size"></a>
###cloud.size
**Type**: `number`  
**Default**: `4`  
<a name="module_heaven..Cloud#rain"></a>
###cloud.rain
**Type**: `boolean`  
**Default**: `false`  
<a name="module_heaven..Cloud.classMethod"></a>
###Cloud.classMethod()
a class method

<a name="module_heaven..Cloud.SPACES"></a>
###const: Cloud.SPACES
a class constant

**Type**: `number`
